
/*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#include "mainwindow.h"
#include "ui_mainwindow.h"
#include "getfilelist.h"

#define APPNAME FileSynq
#define VERSION 0.1

enum tProcess{SYNC,ANA}Process;

#ifdef pre_release
void MainWindow::keyPressEvent(QKeyEvent* event)
{
    //setWindowTitle(event->text());
    static bool sw = 0;
    if(event->matches(QKeySequence::Cut))
    {
        sw=!sw;
        if(sw)
            ui->menuBar->hide();
        else
            ui->menuBar->show();

    }
}
#endif

MainWindow::MainWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::MainWindow)
{
    ui->setupUi(this);

    //This is for the "Open with"-function from the OS
    QStringList arguments;
    arguments = QCoreApplication::arguments();
    if(arguments.count() > 1)
        open_xml(arguments[1]);
    else
        set_basic_conf();

    init_timer();
    setHeaders();
    setIcons();

    //first initalisation of the variables

    counter = 0;
}

MainWindow::~MainWindow()
{

    delete ui;
}

void MainWindow::init_timer()
{
    sync_timer = new QTimer();
    connect(sync_timer, SIGNAL(timeout()), this, SLOT(syncTimer()));

    analyz_timer = new QTimer();
    connect(analyz_timer, SIGNAL(timeout()), this, SLOT(analyzTimer()));

    getfiles_timer = new QTimer();
    connect(getfiles_timer, SIGNAL(timeout()), this, SLOT(getfilesTimer()));
}


void MainWindow::changeEvent(QEvent *e)
{
    QMainWindow::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}


void MainWindow::on_pbtn_1folder_open_clicked()
{
    QString temp;
    temp = pro.get_f1_path();
    pro.set_f1_path(QFileDialog::getExistingDirectory(
                          this,
                          tr("Select folder")));
    if(pro.get_f1_path().isEmpty())
        pro.set_f1_path(temp);

     ui->le_1folder->setText(pro.get_f1_path());
}

void MainWindow::on_pbtn_2folder_open_clicked()
{
    QString temp;
    temp = pro.get_f2_path();
    pro.set_f2_path(QFileDialog::getExistingDirectory(
                          this,
                          tr("Select folder")));
    if(pro.get_f2_path().isEmpty())
        pro.set_f2_path(temp);

     ui->le_2folder->setText(pro.get_f2_path());
}

void MainWindow::on_pbtn_mode_clicked()
{


   if (pro.get_mode() == 0)
    {
       QPixmap mode_map1(":/trolltech/styles/commonstyle/images/left-128.png"); // because of windows, on linux/unix it works without new-defination
       mode_map.load(":/trolltech/styles/commonstyle/images/left-128.png");     //horible!!
       ui->pbtn_mode->setIcon(mode_map1);
       ui->tl_hl_f2->setText(tr("Source folder"));
       ui->tl_hl_f1->setText(tr("Sync folder"));
       pro.set_mode(1);
    }
   else
   {
       QPixmap mode_map2(":/trolltech/styles/commonstyle/images/right-128.png");
       mode_map.load(":/trolltech/styles/commonstyle/images/right-128.png");
       ui->pbtn_mode->setIcon(mode_map2);
       ui->tl_hl_f1->setText(tr("Source folder"));
       ui->tl_hl_f2->setText(tr("Sync folder"));
       pro.set_mode(0);
   }


}

void MainWindow::on_pbtn_cancle_clicked()
{
    pro.set_end_status(tr("Canceled by user"));
    pro.set_cancel(1);
}

void MainWindow::on_actionStop_activated()
{
    pro.set_end_status(tr("Canceled by user"));
    pro.set_cancel(1);
}

void MainWindow::disenable_pbtn()
{
    ui->pbtn_analyze->setEnabled(0);
    ui->pbtn_syncronize->setEnabled(0);
    ui->actionSync->setEnabled(0);
    ui->actionAnalyze->setEnabled(0);
    ui->pbtn_1folder_open->setEnabled(0);
    ui->pbtn_2folder_open->setEnabled(0);
    ui->pbtn_mode->setEnabled(0);

    ui->pbtn_cancle->setEnabled(1);
    ui->pbtn_clear->setEnabled(0);
    ui->actionStop->setEnabled(1);

    ui->tw_main_tabs->setTabEnabled(1,0);
}

void MainWindow::on_pbtn_syncronize_clicked()
{

    clear_Tw();

    disenable_pbtn();

    Process = SYNC;
    process__dircheck();

}

void MainWindow::on_pbtn_analyze_clicked()
{

    clear_Tw();

    disenable_pbtn();

    Process = ANA;
    process__dircheck();

}

void MainWindow::on_actionSync_activated()
{

    clear_Tw();

    disenable_pbtn();

    Process = SYNC;
    process__dircheck();

}


void MainWindow::on_actionAnalyze_activated()
{

    clear_Tw();

    disenable_pbtn();

    Process = ANA;
    process__dircheck();

}


void MainWindow::critical_W(QString text)
{
    QMessageBox::critical(this, tr("FileSynq"),
                                   text.toLocal8Bit(),
                                   QMessageBox::Ok );
    reset();

}

bool MainWindow::copyFile(QFileInfo input, QFileInfo output)
{

    QFile f1_file(input.absoluteFilePath());
    QFile f2_file(output.absoluteFilePath());

    QDir makepath;
    QDir existpath(output.absolutePath());

    if (f2_file.exists())
        f2_file.remove();

    if (!existpath.exists())
        makepath.mkpath(output.absolutePath());



    ui->tw_files->item(counter,5)->setTextColor(Qt::black);
    ui->tw_files->item(counter,5)->setText(tr("Opening.."));

    if (!f1_file.open(QIODevice::ReadOnly | QIODevice::Text))
    {
        ui->tw_files->item(counter,5)->setTextColor(Qt::red);
        ui->tw_files->item(counter,5)->setText(tr("Failed!"));

    }
    else
    {
        ui->tw_files->item(counter,5)->setTextColor(Qt::black);
        ui->tw_files->item(counter,5)->setText(tr("Copying..."));

        if ( f1_file.copy(output.absoluteFilePath() ) )
        {

            ui->tw_files->item(counter,5)->setTextColor(Qt::darkGreen);
            ui->tw_files->item(counter,5)->setText(tr("Copied!"));

        }
        else
        {
            ui->tw_files->item(counter,5)->setTextColor(Qt::red);
            ui->tw_files->item(counter,5)->setText(tr("Failed!"));

        }
    }

    f1_file.close();
    f2_file.close();

    return 0;
}

void MainWindow::syncTimer()     //conected function to <sync_timer>
{
    if(pro.is_canceled())
    {
        sync_timer->stop();
        //pro.set_end_status(tr("Aborted by user"));
        open_summary(0);
        reset();
    }
    else
    {
        if(counter < f1_files.count())
        {
            QFileInfo f1_file(f1_files[counter]);
            QFileInfo f2_file(f2_files[counter]);
            if (!f2_file.exists())                                   // if the file does not exist in the sync-folder
            {
                addRow(counter,tr("Not exist"),f1_file,f2_file,Qt::darkRed);
                pro.nex_files_inc(); //nex_files++
                copyFile(f1_file,f2_file);
            }
            else
            {
                if(f1_file.lastModified() > f2_file.lastModified())  // if the file wos modified in the sync-folder
                {
                    addRow(counter,tr("Modified"),f1_file,f2_file,Qt::blue);
                    pro.mod_files_inc(); //mod_files++
                    copyFile(f1_file,f2_file);
                }
                else
                {
                    addRow(counter,tr("Skiped"),f1_file,f2_file,Qt::darkGreen);
                    pro.ex_files_inc(); //ex_files++
                }

            }
            set_file_share();
            ui->tw_files->scrollToBottom();
            counter++;
        }
        else
        {
            sync_timer->stop();

            ui->statusBar->showMessage(tr("Finished..."),5000);

            //pro.set_end_status(tr("Synchronisation successful"));
            open_summary(0);
            reset();
        }
        if (!f1_files.count() <= 0)
            ui->pb_progress->setValue((counter*100)/f1_files.count());
        }
}

void MainWindow::analyzTimer()    //conected function to <analyz_timer>
{
    if(pro.is_canceled())
    {
        analyz_timer->stop();

        //pro.set_end_status(tr("Aborted by user"));
        open_summary(1);
        reset();
    }
    else
    {
        if(counter < f1_files.count())
        {
            QFileInfo f1_file(f1_files[counter]);
            QFileInfo f2_file(f2_files[counter]);
            if (!f2_file.exists())
            {

                addRow(counter,tr("Not exist"),f1_file,f2_file,Qt::darkRed);
                pro.nex_files_inc(); //nex_files++
            }
            else
            {
                if(f1_file.lastModified() > f2_file.lastModified()) //if the file wos modified in the sync-folder
                {
                   addRow(counter,tr("Modified"),f1_file,f2_file,Qt::blue);
                   pro.mod_files_inc(); //mod_files++
                }
                else
                {
                   addRow(counter,tr("Exist"),f1_file,f2_file,Qt::darkGreen);
                   pro.ex_files_inc();
                }

            }
            set_file_share();
            ui->tw_files->scrollToBottom();
            counter++;
        }
        else
        {
           analyz_timer->stop();

           ui->statusBar->showMessage(tr("Finished..."),5000);

           //pro.set_end_status(tr("Analysis successful"));
           open_summary(1);
           reset();
        }

       if (f1_files.count() > 0)
        ui->pb_progress->setValue((counter*100)/f1_files.count());
   }
}

QString str;

void MainWindow::getfilesTimer()
{

    static unsigned long int gfl_counter = 0;

    if(!dirI->hasNext() || pro.is_canceled())
        {
            getfiles_timer->stop();
            gfl_counter = 0;
            //destroys the "busy indicator"
            ui->pb_progress->setValue(0);
            ui->pb_progress->setMaximum(100);

            if (Process == SYNC)
            {
                ui->statusBar->showMessage(tr("Syncronistion process..."));
                sync_timer->start();
            }
            else
            {
                ui->statusBar->showMessage(tr("Analysing process..."));
                analyz_timer->start();
            }

        }
   else
        {

              dirI->next();

#ifdef WIN32
              str = dirI->filePath().replace("/","\\");
#else
              str = dirI->filePath().replace("\\","/");
#endif
              f1_files.append(str);

              f2_files.append(str.replace(pro.get_f1_path(),pro.get_f2_path()));
             // setWindowTitle(QString().number(sizeof(pro)));

              ui->statusBar->showMessage(tr("Getting filelist... ( ")+QString().number(++gfl_counter)+ tr(" Files)"));
         }


}

/*
    this function checks the accurecy of the choosen dirs
    sourcedir= there are the source files which have to be copied
    syncdir = the source files will be copied to this dir
*/

void MainWindow::process__dircheck()
{

    if (pro.isPathEmpty())
        critical_W(tr("There are no folders to synchronize/analyze!"));
    else
    {
        if(pro.isPossiblePaths(pro.get_mode()))
            critical_W(tr("The Sync-Folder must not be in the Source-Folder"));
        else
        {
            if(!pro.isPathReadable())
                critical_W(tr("You have no acces to one of the folders!"));
            else
            {
                process__getfilelist();
            }
    }
    }
}

/*
    this function sets the correct parameters for QDirIterator which is used to get the filelist
*/

void MainWindow::process__getfilelist(void)
{
    pro.set_start_time(pro.get_start_time().currentTime());

    if(pro.get_mode() == 1)
        pro.flip_fpaths();

        if(pro.get_add_subdir())
        {
            if (!pro.get_add_hidden() && pro.get_follow_sym()) // if =  0 1
                dirI = new QDirIterator(pro.get_f1_path(),QDir::NoDotAndDotDot | QDir::Files, QDirIterator::Subdirectories );

            if (pro.get_add_hidden() && pro.get_follow_sym()) // if =  1 1
                dirI = new QDirIterator(pro.get_f1_path(),QDir::NoDotAndDotDot | QDir::Files  | QDir::Hidden, QDirIterator::Subdirectories);

            if (!pro.get_add_hidden() && !pro.get_follow_sym()) // if =  0 0
                dirI = new QDirIterator(pro.get_f1_path(),QDir::NoDotAndDotDot | QDir::Files | QDir::NoSymLinks , QDirIterator::Subdirectories);

            if (pro.get_add_hidden() && !pro.get_follow_sym()) // if =  1 0
                dirI = new QDirIterator(pro.get_f1_path(),QDir::NoDotAndDotDot | QDir::Files | QDir::NoSymLinks | QDir::Hidden, QDirIterator::Subdirectories );
        }
        else
        {
            if (!pro.get_add_hidden() && pro.get_follow_sym()) // if =  0 1
                dirI = new QDirIterator(pro.get_f1_path(),QDir::NoDotAndDotDot | QDir::Files );

            if (pro.get_add_hidden() && pro.get_follow_sym()) // if =  1 1
                dirI = new QDirIterator(pro.get_f1_path(),QDir::NoDotAndDotDot | QDir::Files  | QDir::Hidden);

            if (!pro.get_add_hidden() && !pro.get_follow_sym()) // if =  0 0
               dirI = new QDirIterator(pro.get_f1_path(),QDir::NoDotAndDotDot | QDir::Files | QDir::NoSymLinks );

            if (pro.get_add_hidden() && !pro.get_follow_sym()) // if =  1 0
                dirI = new QDirIterator(pro.get_f1_path(),QDir::NoDotAndDotDot | QDir::Files | QDir::NoSymLinks | QDir::Hidden );
        }

        //creates an "busy indicator"
        ui->pb_progress->setValue(1);
        ui->pb_progress->setMaximum(0);

        getfiles_timer->start();

}


void MainWindow::remove_not_needed_files()         //remove all files in the sync-folder which are in the syncdir
                                                   //but not in the sourcedir
{
    QFile file;

    for (int i = 0; i <f2_files_fake.count();i++)
    {
        QFileInfo f1_file(f1_files_fake[i]);

        if (!f1_file.exists())
            file.remove(f2_files_fake[i]);
    }
    file.close();
}





void MainWindow::reset()  // resets all variables used in the app
{
    counter = 0;
    pro.set_ex_files(0);
    pro.set_mod_files(0);
    pro.set_nex_files(0);

    pro.set_cancel(0);

    f1_files.clear();
    f2_files.clear();

    if(pro.get_mode() == 1)
        pro.flip_fpaths();

    ui->pb_progress->setValue(0);
    ui->pbtn_analyze->setEnabled(1);
    ui->pbtn_syncronize->setEnabled(1);
    ui->pbtn_cancle->setEnabled(0);
    ui->pbtn_clear->setEnabled(1);
    ui->pbtn_1folder_open->setEnabled(1);
    ui->pbtn_2folder_open->setEnabled(1);
    ui->pbtn_mode->setEnabled(1);
    ui->actionStop->setEnabled(0);
    ui->actionSync->setEnabled(1);
    ui->actionAnalyze->setEnabled(1);
    ui->tw_main_tabs->setTabEnabled(1,1);

}

void MainWindow::remove_excl_file_types()
{
    int count = pro.get_excl_file_types().count();

    for(int i = 0 ; i < count ; i++)
    {
        for(int a = 0 ; a < f1_files.count() ; a++)
        {
            if(f1_files[a].endsWith(QString("." + pro.get_excl_file_types().at(i))))
            {
                f1_files.removeAt(a);
                f2_files.removeAt(a);
                a--;
            }
        }
    }
}

void MainWindow::on_pbtn_clear_clicked()
{

    clear_Tw();

}

void MainWindow::addRow(int row,QString status,QFileInfo f1_file,QFileInfo f2_file,QColor color)  //add the needed rows
{


    ui->tw_files->insertRow(ui->tw_files->rowCount());
if (pro.get_mode() == 0)
    {
    QTableWidgetItem *item1 = new QTableWidgetItem;
    ui->tw_files->setItem(row,0,item1);
    item1->setTextColor(color);
    item1->setText(f1_file.absolutePath());


    QTableWidgetItem *item2 = new QTableWidgetItem;
    ui->tw_files->setItem(row,1,item2);
    item2->setTextColor(color);
    item2->setText(f1_file.fileName());

    QTableWidgetItem *item4 = new QTableWidgetItem;
    ui->tw_files->setItem(row,3,item4);
    item4->setTextColor(color);
    item4->setText(f2_file.absolutePath());

    QTableWidgetItem *item5 = new QTableWidgetItem;
    ui->tw_files->setItem(row,4,item5);
    item5->setTextColor(color);
    item5->setText(f2_file.fileName());
}
else
{
    QTableWidgetItem *item1 = new QTableWidgetItem;
    ui->tw_files->setItem(row,0,item1);
    item1->setTextColor(color);
    item1->setText(f2_file.absolutePath());

    QTableWidgetItem *item2 = new QTableWidgetItem;
    ui->tw_files->setItem(row,1,item2);
    item2->setTextColor(color);
    item2->setText(f2_file.fileName());

    QTableWidgetItem *item4 = new QTableWidgetItem;
    ui->tw_files->setItem(row,3,item4);
    item4->setTextColor(color);
    item4->setText(f1_file.absolutePath());

    QTableWidgetItem *item5 = new QTableWidgetItem;
    ui->tw_files->setItem(row,4,item5);
    item5->setTextColor(color);
    item5->setText(f1_file.fileName());
}

    QTableWidgetItem *item3 = new QTableWidgetItem;
    ui->tw_files->setItem(row,2,item3);
    item3->setIcon(mode_map);

    QTableWidgetItem *item6 = new QTableWidgetItem;
    ui->tw_files->setItem(row,5,item6);
    item6->setTextColor(color);
    item6->setText(status);

}

void MainWindow::setHeaders() //sets the header_geometry of tw_files
{
     ui->tw_files->setColumnWidth(0,265);
     ui->tw_files->setColumnWidth(1,150);
     ui->tw_files->setColumnWidth(2,25);
     ui->tw_files->setColumnWidth(3,265);
     ui->tw_files->setColumnWidth(4,150);
//     ui->tw_files->setColumnWidth(5,100);
}

void MainWindow::setIcons()
{
    QIcon open_map(":/icons/open");
    ui->actionOpen->setIcon(open_map);
    ui->actionOpen_menu->setIcon(open_map);
    QIcon save_map(":/icons/save");
    ui->actionSave->setIcon(save_map);
    ui->actionSave_menu->setIcon(save_map);
    QIcon saveas_map(":/icons/saveas");
    ui->actionSave_as_menu->setIcon(saveas_map);
    QIcon close_map(":/icons/pro_close");
    ui->actionClose_project->setIcon(close_map);
    QIcon sync_map(":/icons/sync");
    ui->actionSync->setIcon(sync_map);
    ui->pbtn_syncronize->setIcon(sync_map);
    QIcon analys_map(":/icons/anal");
    ui->actionAnalyze->setIcon(analys_map);
    ui->pbtn_analyze->setIcon(analys_map);
    QIcon cancel_map(":icons/cancel");
    ui->actionStop->setIcon(cancel_map);
    ui->pbtn_cancle->setIcon(cancel_map);

    mode_map.load(":/trolltech/styles/commonstyle/images/right-128.png");
    ui->pbtn_mode->setIcon(mode_map); 
}

void MainWindow::clear_Tw()
{

    int count = ui->tw_files->rowCount();
    for(int i = 0; i< count ;i++)
    {
    ui->tw_files->removeRow(0);
    }

}

void MainWindow::on_actionSave_activated()
{

save_project(0);

}

void MainWindow::on_actionOpen_activated()
{

open_project();

}

void MainWindow::open_project()
{

    QString filename = QFileDialog::getOpenFileName(this,tr("Open Project"),NULL,tr("Project Files(*.qsync)"));

    if (!filename.isEmpty())
    {
    open_xml(filename);
    }
}

void MainWindow::save_project(bool saveAs)
{
    pro.temp = pro.get_proFilepath();
    if(pro.get_proFilepath().isEmpty() || saveAs)
        pro.set_proFilepath(QFileDialog::getSaveFileName(this,tr("Save Project"),NULL,tr("Project Files(*.qsync)")));

    if (!pro.get_proFilepath().isEmpty())
    {
        if(!pro.get_proFilepath().endsWith(".qsync"))
            pro.get_proFilepath().append(".qsync");

        save_xml(pro.get_proFilepath());
    }
    else
        pro.set_proFilepath(pro.temp);

}

void MainWindow::save_xml(QString filepath)
{

    QFile file(filepath);

    file.open( QIODevice::WriteOnly );
    QXmlStreamWriter stream(&file);

       stream.setAutoFormatting(true);
       stream.writeStartDocument();
       stream.writeStartElement("preferences");
       stream.writeTextElement("folder1", pro.get_f1_path());
       stream.writeTextElement("folder2", pro.get_f2_path());
       stream.writeTextElement("excl_file_types", pro.get_excl_file_types().join(","));
       stream.writeTextElement("mode", QString::number(pro.get_mode()));
       stream.writeTextElement("add_subdir", QString::number(pro.get_add_subdir()));
       stream.writeTextElement("add_hidden", QString::number(pro.get_add_hidden()));
       stream.writeTextElement("follow_sym", QString::number(pro.get_follow_sym()));
       stream.writeTextElement("remove_non_existant", QString::number(pro.get_remove_non_existant()));
       stream.writeEndElement();
       stream.writeEndDocument();

       file.close();

       QFileInfo winTitle(filepath);

       QString winTitle_qstr = winTitle.fileName();
       setWindowTitle( winTitle_qstr +" - FileSynq");

}

void MainWindow::open_xml(QString filepath)
{

    if(!filepath.endsWith(".qsync"))
    {
      critical_W(tr("FileSynq is not able to open such files!"));
    }
    else
    {
        pro.set_proFilepath(filepath);
        QFile file(filepath);

        file.open( QIODevice::ReadOnly );

        QXmlStreamReader stream(&file);

        while (!stream.atEnd())
        {

                if(stream.name() == "folder1")
                    pro.set_f1_path(stream.readElementText());

                if(stream.name() == "folder2")
                    pro.set_f2_path(stream.readElementText());

                if(stream.name() == "excl_file_types")
                    pro.set_excl_file_types(stream.readElementText().split(","));

                if(stream.name() == "mode")
                    pro.set_mode(stream.readElementText().toInt());

                if(stream.name() == "add_subdir")
                    pro.set_add_subdir(stream.readElementText().toInt());

                if(stream.name() == "add_hidden")
                    pro.set_add_hidden(stream.readElementText().toInt());

                if(stream.name() == "follow_sym")
                    pro.set_follow_sym(stream.readElementText().toInt());

                if(stream.name() == "remove_non_existant")
                    pro.set_remove_non_existant(stream.readElementText().toInt());

                stream.readNext();
        }

        if (stream.hasError())
        {

           critical_W(tr("An error occured while opening Project!"));

        }
        else
        {
          set_gui_to_conf();

          QFileInfo winTitle(filepath);

          QString winTitle_qstr = winTitle.fileName();
          setWindowTitle( winTitle_qstr +" - FileSynq");

      }


       file.close();
   }

}

void MainWindow::set_gui_to_conf()  //when you load a project, this function sets the correct gui
{
    ui->le_1folder->setText(pro.get_f1_path());
    ui->le_2folder->setText(pro.get_f2_path());

    ui->le_ex_files->setText(pro.get_excl_file_types().join(","));

    ui->cb_subdir->setChecked(pro.get_add_subdir());
    ui->cb_hidden->setChecked(pro.get_add_hidden());
    ui->cb_sym->setChecked(pro.get_follow_sym());
    ui->cb_rm_non_exist->setChecked(pro.get_remove_non_existant());

    if (pro.get_mode() == 0)
     {
        mode_map.load(":/trolltech/styles/commonstyle/images/right-128.png");
        ui->pbtn_mode->setIcon(mode_map);
     }
    else
    {
        mode_map.load(":/trolltech/styles/commonstyle/images/left-128.png");
        ui->pbtn_mode->setIcon(mode_map);
    }
}

void MainWindow::set_basic_conf(void)
{
    pro.set_add_subdir(1);
    pro.set_add_hidden(0);
    pro.set_remove_non_existant(0);
    pro.set_follow_sym(0);
    pro.set_mode(0);
    pro.set_f1_path("");
    pro.set_f2_path("");
    pro.set_proFilepath("");

    pro.set_cancel(0);

}

void MainWindow::set_file_share()  //this function displays the file count of existan files,etc
{
    ui->tl_exist_files->setText("Existant Files: "+ QString().number( pro.get_ex_files()));
    ui->tl_modified_files->setText("Modified Files: "+ QString().number(pro.get_mod_files()));
    ui->tl_non_existant_files->setText("Non-Existant Files: "+ QString().number(pro.get_nex_files()));

}

void MainWindow::on_actionAbout_Qt_activated()
{
    QApplication::aboutQt();
}

void MainWindow::on_actionAbout_QFilesync_activated()
{
    about a;
    a.exec();
}

void MainWindow::on_actionClose_menu_activated()
{
    QApplication::quit();
}

void MainWindow::on_actionSave_menu_activated()
{
    save_project(0);
}

void MainWindow::on_actionSave_as_menu_activated()
{
    save_project(1);
}

void MainWindow::on_actionOpen_menu_activated()
{
   open_project();
}

void MainWindow::open_summary(bool process)
{
    pro.set_end_time(pro.get_end_time().currentTime());

    summary sum;
    sum.set_project(&pro,process);

    sum.exec();
}

void MainWindow::apply_options()
{
    QString str;
    str = ui->le_ex_files->text();
    pro.set_excl_file_types(str.split(","));

        pro.set_add_subdir(ui->cb_subdir->isChecked());
        pro.set_add_subdir(ui->cb_subdir->isChecked());
        pro.set_follow_sym(ui->cb_sym->isChecked());
        pro.set_remove_non_existant(ui->cb_rm_non_exist->isChecked());
}


void MainWindow::on_cb_subdir_clicked()
{
    pro.set_add_subdir(ui->cb_subdir->isChecked());
}

void MainWindow::on_cb_hidden_clicked()
{
    pro.set_add_subdir(ui->cb_subdir->isChecked());
}

void MainWindow::on_cb_sym_clicked()
{
    pro.set_follow_sym(ui->cb_sym->isChecked());
}

void MainWindow::on_cb_rm_non_exist_clicked()
{
    pro.set_remove_non_existant(ui->cb_rm_non_exist->isChecked());
}

void MainWindow::on_le_ex_files_textChanged(QString str)
{
    pro.set_excl_file_types(str.split(","));
}

void MainWindow::close_project()
{
    reset();
    set_basic_conf();
    set_gui_to_conf();
    clear_Tw();
    setWindowTitle(tr("FileSynq 0.1"));
}

void MainWindow::on_actionClose_project_activated()
{
   close_project();
}
