/*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
*/

#ifndef MAINWINDOW_H
#define MAINWINDOW_H


#include <QMainWindow>
#include <QFileInfo>
#include <QDir>
#include <QFileDialog>
#include <QMessageBox>
#include <QtXml>
#include <QDirIterator>
//#include <QKeyEvent>


#include "about.h"
#include "summary.h"
#include "project_data/project.h"

namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow {
    Q_OBJECT
public:
    MainWindow(QWidget *parent = 0);
    ~MainWindow();

protected:
    void changeEvent(QEvent *e);


private:
    Ui::MainWindow *ui;

#ifdef pre_release
    void keyPressEvent(QKeyEvent* event);
#endif

    void critical_W(QString);
    bool copyFile(QFileInfo ,QFileInfo);

    void process__dircheck(void);
    void process__getfilelist(void);
    void reset(void);
    void remove_not_needed_files(void);
    void remove_excl_file_types(void);
    void addRow(int,QString,QFileInfo,QFileInfo,QColor);

    void setHeaders(void);
    void setIcons(void);

    void clear_Tw(void);
    void set_gui_to_conf(void);
    void set_basic_conf(void);
    void set_file_share();  //exist files; modified files; non-exist files;
    void init_timer(void);

    void save_project(bool);
    void open_project(void);
    void save_xml(QString);
    void open_xml(QString);
    void close_project(void);
    void apply_options(void);

    void disenable_pbtn(void);

    void open_summary(bool);


    unsigned long int counter;

    QStringList f1_files, f2_files;
    QStringList f1_files_fake, f2_files_fake;

    QTimer *sync_timer;
    QTimer *analyz_timer;
    QTimer *getfiles_timer;

    QDirIterator *dirI;


    QPixmap mode_map; // 0 = from left to right -> | 1 = from right to left <-

    //this object includ all project data:
    project pro;

private slots:
    //PushButtons:
    void on_le_ex_files_textChanged(QString );
    void on_cb_rm_non_exist_clicked();
    void on_cb_sym_clicked();
    void on_cb_hidden_clicked();
    void on_cb_subdir_clicked();
    void on_pbtn_1folder_open_clicked();
    void on_pbtn_syncronize_clicked();
    void on_pbtn_analyze_clicked();
    void on_pbtn_cancle_clicked();
    void on_pbtn_2folder_open_clicked();
    void on_pbtn_clear_clicked();
    void on_pbtn_mode_clicked();
    //Actions:
    void on_actionSync_activated();
    void on_actionAnalyze_activated();
    void on_actionSave_activated();
    void on_actionOpen_activated();
    void on_actionStop_activated();
    void on_actionAbout_Qt_activated();
    void on_actionAbout_QFilesync_activated();
    void on_actionClose_menu_activated();
    void on_actionOpen_menu_activated();
    void on_actionSave_as_menu_activated();
    void on_actionSave_menu_activated();
    void on_actionClose_project_activated();
    //Timer:
    void syncTimer();
    void analyzTimer();
    void getfilesTimer();



};

#endif // MAINWINDOW_H
